summaryrefslogtreecommitdiffstats
path: root/core/java/android/bluetooth/BluetoothDevice.java
diff options
context:
space:
mode:
authorMatthew Xie <mattx@google.com>2011-10-27 11:31:12 -0700
committerMatthew Xie <mattx@google.com>2011-10-27 14:28:46 -0700
commitae5839dcad76625313e6736d69eeaf37af435a3f (patch)
treef3850ea866d170fea643b0023d4a22531f59acaa /core/java/android/bluetooth/BluetoothDevice.java
parent2333a02e152616c4b982c149ea2a5c9e9615e274 (diff)
downloadframeworks_base-ae5839dcad76625313e6736d69eeaf37af435a3f.zip
frameworks_base-ae5839dcad76625313e6736d69eeaf37af435a3f.tar.gz
frameworks_base-ae5839dcad76625313e6736d69eeaf37af435a3f.tar.bz2
Make public APIs of ACTION_UUID, getUuids, and fetchUuidsWithSdp
Give APP a way to find out if a service is supported by a remote device bug 5487202 Change-Id: Ie778b3227f29a24cdf61fa0365b82f9a45d439dc
Diffstat (limited to 'core/java/android/bluetooth/BluetoothDevice.java')
-rw-r--r--core/java/android/bluetooth/BluetoothDevice.java35
1 files changed, 23 insertions, 12 deletions
diff --git a/core/java/android/bluetooth/BluetoothDevice.java b/core/java/android/bluetooth/BluetoothDevice.java
index 4cb8220..e8c368c 100644
--- a/core/java/android/bluetooth/BluetoothDevice.java
+++ b/core/java/android/bluetooth/BluetoothDevice.java
@@ -249,11 +249,10 @@ public final class BluetoothDevice implements Parcelable {
* <p> Always contains the extra field {@link #EXTRA_DEVICE}
* <p> Always contains the extra filed {@link #EXTRA_UUID}
* <p>Requires {@link android.Manifest.permission#BLUETOOTH} to receive.
- * @hide
*/
@SdkConstant(SdkConstantType.BROADCAST_INTENT_ACTION)
public static final String ACTION_UUID =
- "android.bleutooth.device.action.UUID";
+ "android.bluetooth.device.action.UUID";
/**
* Broadcast Action: Indicates a failure to retrieve the name of a remote
@@ -770,7 +769,18 @@ public final class BluetoothDevice implements Parcelable {
return false;
}
- /** @hide */
+ /**
+ * Returns the supported features (UUIDs) of the remote device.
+ *
+ * <p>This method does not start a service discovery procedure to retrieve the UUIDs
+ * from the remote device. Instead, the local cached copy of the service
+ * UUIDs are returned.
+ * <p>Use {@link #fetchUuidsWithSdp} if fresh UUIDs are desired.
+ * <p>Requires {@link android.Manifest.permission#BLUETOOTH}.
+ *
+ * @return the supported features (UUIDs) of the remote device,
+ * or null on error
+ */
public ParcelUuid[] getUuids() {
try {
return sService.getRemoteUuids(mAddress);
@@ -779,18 +789,19 @@ public final class BluetoothDevice implements Parcelable {
}
/**
* Perform a SDP query on the remote device to get the UUIDs
* supported. This API is asynchronous and an Intent is sent,
* with the UUIDs supported by the remote end. If there is an error
* in getting the SDP records or if the process takes a long time,
* an Intent is sent with the UUIDs that is currently present in the
* cache. Clients should use the {@link #getUuids} to get UUIDs
* is SDP is not to be performed.
*
- * @return False if the sanity check fails, True if the process
+ * @return False if the sanity check fails, True if the process
* of initiating an ACL connection to the remote device
* was started.
- * @hide
*/
public boolean fetchUuidsWithSdp() {
try {
@@ -779,18 +789,19 @@ public final class BluetoothDevice implements Parcelable {
}
/**
- * Perform a SDP query on the remote device to get the UUIDs
- * supported. This API is asynchronous and an Intent is sent,
- * with the UUIDs supported by the remote end. If there is an error
- * in getting the SDP records or if the process takes a long time,
- * an Intent is sent with the UUIDs that is currently present in the
- * cache. Clients should use the {@link #getUuids} to get UUIDs
- * is SDP is not to be performed.
+ * Perform a service discovery on the remote device to get the UUIDs supported.
+ *
+ * <p>This API is asynchronous and {@link #ACTION_UUID} intent is sent,
+ * with the UUIDs supported by the remote end. If there is an error
+ * in getting the SDP records or if the process takes a long time,
+ * {@link #ACTION_UUID} intent is sent with the UUIDs that is currently
+ * present in the cache. Clients should use the {@link #getUuids} to get UUIDs
+ * if service discovery is not to be performed.
+ * <p>Requires {@link android.Manifest.permission#BLUETOOTH}.
*